@@ -41,11 +41,18 @@ class GitProject:
 
     @staticmethod
     def get_branch():
+        if os.getenv("CI_MERGE_REQUEST_SOURCE_BRANCH_NAME"):
+            return os.getenv("CI_MERGE_REQUEST_SOURCE_BRANCH_NAME")
+        if os.getenv("CI_BUILD_REF_NAME"):
+            return os.getenv("CI_BUILD_REF_NAME")
         return open(os.path.join(GitProject.git_path(), 'HEAD'), 'r').read().split('heads/')[-1].strip()
 
     @staticmethod
     def git_path():
-        current_path = os.path.abspath(os.getcwd())
+        if os.getenv("CI_PROJECT_DIR"):
+            current_path = os.getenv('CI_PROJECT_DIR')
+        else:
+            current_path = os.path.abspath(os.getcwd())
         return os.path.join(current_path, '.git')
 
     @staticmethod
@@ -78,9 +85,9 @@ class GitProject:
         parse = GitProject.git_url_parse()
         return f'{parse.scheme}://{parse.hostname}{parse.path}'
 
-    def push_changelog(self, changelog, file_name="CHANGELOG.md"):
+    def push_changelog(self, changelog, branch=None, file_name="CHANGELOG.md"):
         data = {
-            'branch': self.branch,
+            'branch': branch if branch else self.branch,
             'commit_message': 'changelog prepare to release',
             'actions': [
                 {
